parse_bool

Function parse_bool 

pub fn parse_bool(val: &str) -> Result<bool>
Parse a string as a boolean value, returning an error if it is neither truthy nor falsey.

Returns

  • Ok(true) - for truthy values (is_truthy)
  • Ok(false) - for falsey values (is_falsey), including empty
  • Err(_) - for any other value